<?php
/**
 * formativ.net Authentication Plugin
 * External MySQL Database Authentication.
 * 
 * @package    Joomla.fnetcontent
 * @subpackage Authentication.fnetauth
 * 
 * @version 1.1.1
 * @author Thomas Langer
 * @copyright 2016 formativ.net oHG
 * 
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

class plgAuthenticationFnetAuth extends JPlugin {
	private $cFrontentUsersIDs= array();

	/**
	 * This method should handle any authentication and report back to the subject
	 *
	 * @access	public
	 * @param	array	$credentials	Array holding the user credentials
	 * @param	array	$options		Array of extra options
	 * @param	object	$response		Authentication response object
	 * @return	boolean
	 * @since	1.5
	 */
	function onUserAuthenticate($credentials, $options, &$response) {
		
		// Keine Backend Authentifizierung !!!
		if (JFactory::getApplication()->isAdmin() && !$this->params->get('backendLogin', 0)) {
			return;
		}
		
		// Joomla does not like blank passwords
		if (empty($credentials['password']))
		{
			$response->status        = JAuthentication::STATUS_FAILURE;
			$response->error_message = JText::_('JGLOBAL_AUTH_EMPTY_PASS_NOT_ALLOWED');

			return;
		}
		
		// Joomla Konfiguration laden
		$cApp = JFactory::getApplication();
		
		// Plugin Parameter laden
		$cParams=$this->params;

		//Mit Datenbank verbinden
		$cDB = JFactory::getDBO();
		
		// Plugin-Einstellungen Feldnamen und User Tabelle
		$cDBFieldUserID    = $cParams->get('cDBFieldID', 'id');
		$cDBFieldUsername  = $cParams->get('cDBFieldUsername', 'login');
		$cDBFieldPassword  = $cParams->get('cDBFieldPassword', 'password');
		$cDBFieldBlock     = $cParams->get('cDBFieldBlock', 'block');
		$cDBFieldLastVisit = $cParams->get('cDBFieldLastVisit','lastvisitdate');
		$cDBPasswordType   = $cParams->get('cDBPasswordType',  'SHA1');
		$cDBTable = $cParams->get('cDBTable','user');

		// Passwort verschlüsseln
		switch ($cDBPasswordType) {
			case 'MD5':
				$cUserPassword = md5($credentials['password']);
				break;
			case 'PLAIN':
				$cUserPassword = $credentials['password'];
				break;
			case 'SHA1':
			default:
				$cUserPassword = sha1($credentials['password']);
				break;
		}
		
		// User authentifizieren in Tabelle Suchen
		$cQueryString = $cDB->getQuery(true);
		$cQueryString->select('*');
		$cQueryString->from($cDBTable);
		$cQueryString->where($cDBFieldUsername.'="'.$credentials['username'].'" and '.$cDBFieldPassword.'="'.$cUserPassword.'" and '.$cDBFieldBlock.'="0"');

		$cDB->setQuery($cQueryString);
		$cResultData = $cDB->loadAssoc();

		if ($cResultData) {
			// Ist im Plugin ein Benuter zugeordnet
			$cJoomlaUserID = $cParams->get('cFrontendUserID', 0);
			$cAuthHelperUserLanguage='';
			$cAuthHelperScript = JPATH_ROOT.'/fnetcontent/'.$cParams->get('cAuthenticationHelperScript', '');
			if ($cAuthHelperScript!=''){
				//AuthenticationHelperScript laden
				
				if(file_exists($cAuthHelperScript)) {
					include($cAuthHelperScript);
					$cFrontentUsers= $this->cGetFrontendUserArray($cParams);
					$cAuthHelper = new fnetAuthLoginhelper();
					$cAuthHelperResult = $cAuthHelper->cGetAppAuthentication($cResultData,$cFrontentUsers);
					if (is_array($cAuthHelperResult)){
						$cAuthHelperID=$cAuthHelperResult[0];
						$cAuthHelperUserLanguage=$cAuthHelperResult[1];
						
					} else {
						$cAuthHelperID=$cAuthHelperResult;
					}
					if (array_key_exists($cAuthHelperID,$this->cFrontentUsersIDs)) {
						$cJoomlaUserID = $this->cFrontentUsersIDs[$cAuthHelperID];
					}
				}

				
			}
			if ($cJoomlaUserID > 0) {
				//Daten des Joomla Users mit der Id=$cJoomlaUserID laden
				$cDB = JFactory::getDbo();
				$cQueryString = $cDB->getQuery(true);
				$cQueryString->select('*');
				$cQueryString->from('#__users');
				$cQueryString->where('id=' . $cDB->quote($cJoomlaUserID) . ' limit 1');

				$cDB->setQuery($cQueryString);
				$cResult = $cDB->loadObject();
				if ($cResult){
					// Benutzer gefunden -> User erfolgreich authentifiziert
					// User-ID in Session Speichern
					$session = JFactory::getSession();
					$session->set('FnetAuthUserID', $cResultData[$cDBFieldUserID]);
					$session->set('FnetAuthUserLastVisitDate', $cResultData[$cDBFieldLastVisit]);

					if ($cParams->get('cLoginLog',0)==1){
						// Lastvisit in DB-Tabelle aktualisieren
						$cQueryString = $cDB->getQuery(true);

						$fields = array(
							$cDB->quoteName($cDBFieldLastVisit) . ' = \''.date('Y-m-d H:i:s').'\''
						);
						$conditions = array(
							$cDB->quoteName($cDBFieldUserID) . ' = '.$cResultData[$cDBFieldUserID]
						);

						$cQueryString->update($cDB->quoteName($cDBTable))->set($fields)->where($conditions);
						$cDB->setQuery($cQueryString);
						$result = $cDB->execute();
					}
					
					// Rückgabe an Joomla
					if ($cAuthHelperUserLanguage!='') {
						$response->language = $cAuthHelperUserLanguage;
					}
					
					$response->type          = 'FnetAuth';
					$response->status        = JAuthentication::STATUS_SUCCESS;
					$response->error_message = '';
					$response->email         = $cResult->email;
					$response->username      = $cResult->username;;
					$response->fullname      = $cResult->name;
					return;
				}
			}
		}
		// User konnte nicht authentifiziert werden
		$response->status = JAuthentication::STATUS_FAILURE;
		$response->error_message = JText::_('JGLOBAL_AUTH_ACCESS_DENIED');
		return false;
	}
	
	
	private function cGetFrontendUserArray($cParams){
		$ret = array();
		$cFrontentUsers= json_decode($cParams->get('cFrontentUsers', NULL));

		foreach($cFrontentUsers->cAccesslevel as $key => $value) {
			if ($cFrontentUsers->cAccesslevel[$key]=='') {
				continue;
			}
			$this->cFrontentUsersIDs[$value] = $cFrontentUsers->cJoomlaUserID[$key];
			$ret[$value]['cAccessLevel']      = $cFrontentUsers->cAccesslevel[$key];
			$ret[$value]['cNotiz']           = $cFrontentUsers->cNotiz[$key];
		}
		return $ret;
	}
}