<?php
/**
 * @version     1.0.4
 * @package     com_fnetcontent
 * @copyright   Copyright (C) 2016 formativ.net oHG. Alle Rechte vorbehalten.
 * @license     GNU General Public License http://www.gnu.org/licenses/gpl.html
 * @author      thomas Langer <langer@formativ.net> - http://www.formativ.net
*/


/**
 * Routing class from com_finder
 *
 * @since  3.3
 */
class FnetContentRouter extends JComponentRouterBase
{
	/**
	 * Build the route for the com_finder component
	 *
	 * @param   array  &$query  An array of URL arguments
	 *
	 * @return  array  The URL arguments to use to assemble the subsequent URL.
	 *
	 * @since   3.3
	 */
	public function build(&$query)
	{
		$segments = array();

		/*
		 * First, handle menu item routes first. When the menu system builds a
		 * route, it only provides the option and the menu item id. We don't have
		 * to do anything to these routes.
		 */
		if (count($query) === 2 && isset($query['Itemid']) && isset($query['option']))
		{
			return $segments;
		}

		/*
		 * Next, handle a route with a supplied menu item id. All system generated
		 * routes should fall into this group. We can assume that the menu item id
		 * is the best possible match for the query but we need to go through and
		 * see which variables we can eliminate from the route query string because
		 * they are present in the menu item route already.
		 */
		if (!empty($query['Itemid']))
		{
			// Get the menu item.
			$item = $this->menu->getItem($query['Itemid']);

			// Check if the view matches.
			if ($item && @$item->query['view'] === @$query['view'])
			{
				unset($query['view']);
			}


			return $segments;
		}

		if(isset($query['fileid'])) {
			$db->setQuery('select alias from #__fnetcontent where id = '.intval($query['fileid']));
			$segments[] = $db->loadResult();
			unset($query['fileid']);
		}
	
		/*
		 * Lastly, handle a route with no menu item id. Fortunately, we only need
		 * to deal with the view as the other route variables are supposed to stay
		 * in the query string.
		 */
		if (isset($query['view']))
		{
			// Add the view to the segments.
			$segments[] = $query['view'];
			unset($query['view']);
		}

		if (isset($query['viewfile']))
		{
			// Add the view to the segments.
			$segments[] = $query['viewfile'];
			//unset($query['viewfile']);
		}
		$total = count($segments);

		for ($i = 0; $i < $total; $i++)
		{
			$segments[$i] = str_replace(':', '-', $segments[$i]);
		}
		
		if (isset($query['task'])) {
			$segments[] = implode('/', explode('.', $query['task']));
			unset($query['task']);
		}
		if (isset($query['view'])) {
			$segments[] = $query['view'];
			unset($query['view']);
		}
		if (isset($query['id'])) {
			$segments[] = $query['id'];
			unset($query['id']);
		}

		return $segments;
	}

	/**
	 * Parse the segments of a URL.
	 * Formats:
	 *
	 * index.php?/fnetcontent/task/id/Itemid
	 *
	 * index.php?/fnetcontent/id/Itemid
	 *
	 * @param   array  &$segments  The segments of the URL to parse.
	 *
	 * @return  array  The URL attributes to be used by the application.
	 *
	 * @since   3.3
	 */
	public function parse(&$segments)
	{
		$total = count($segments);
		$vars = array();
		// Get the active menu item.
		$item = $this->menu->getActive();
		if(array_key_exists('view', $item->query)) {
			$vars['view']=$item->query['view'];
		} else {
			$vars['view']='fnetapplication';
		}
		
		// Check if the view segment is set and it equals search or advanced.
//		if (@$segments[0] === 'clickdemo' || @$segments[0] === 'contact' || @$segments[0] === 'default' || @$segments[0] === 'dummycontent')
//		{
//			$vars['view'] = $segments[0];
//		}
//		else {
//			$vars['view'] = '';
//		}
		if ($segments[0]=='application') {
			$vars['view']='application';
			$db = JFactory::getDBO();
			$alias= str_replace(' ', '', $segments[0]);
			$db->setQuery('select id from #__fnetcontent where alias = "'.$segments[0].'"');
			$vars['fileid'] = $db->loadResult();
		}
		
		// Weitere Segmente verarbeiten. und param1, param2, param3 ... zuweisen
		$c = count($segments);
		while (!empty($segments)) {
			$segment = array_pop($segments);
			$vars['fnetparam'.($c)] = $segment;
			$c--;
		}
	
		return $vars;
	}
}


/**
 * FnetContent router functions
 *
 * These functions are proxys for the new router interface
 * for old SEF extensions.
 *
 * @param   array  &$query  An array of URL arguments
 *
 * @return  array  The URL arguments to use to assemble the subsequent URL.
 *
 * @deprecated  4.0  Use Class based routers instead
 */

function FnetContentBuildRoute(&$query) {
	
	$router = new fnetContentRouter;

	return $router->build($query);
}


/**
 * fnetContent router functions
 *
 * These functions are proxys for the new router interface
 * for old SEF extensions.
 *
 * @param   array  &$segments  The segments of the URL to parse.
 *
 * @return  array  The URL attributes to be used by the application.
 *
 * @deprecated  4.0  Use Class based routers instead
 */
function FnetContentParseRoute($segments) {
	
	$router = new fnetContentRouter;
	
	return $router->parse($segments);
}